@@ -19,7 +19,7 @@ use Plack::Util::Accessor qw/ default_rate rules cache file _match greylist retr
 use Ref::Util             qw/ is_plain_arrayref /;
 use Time::Seconds         qw/ ONE_MINUTE /;
 
-our $VERSION = 'v0.5.5'; # TRIAL
+our $VERSION = 'v0.5.6'; # TRIAL
 
 
 sub prepare_app {
@@ -32,9 +32,6 @@ sub prepare_app {
     my $config = $self->cache_config;
     $self->cache_config($config) unless defined $config;
 
-    my $file = $self->file // die "No cache was set";
-
-    $config->{share_file} = "$file";
     $config->{init_file}                //= 0;
     $config->{unlink_on_exit}           //= !$config->{init_file};
     $config->{serializer}               //= '';
@@ -46,6 +43,10 @@ sub prepare_app {
 
     unless ( $self->cache ) {
 
+      my $file = $self->file // $config->{share_file};
+      die "No cache was set" unless defined $file;
+      $config->{share_file} = "$file";
+
         load Cache::FastMmap;
 
         my $cache = Cache::FastMmap->new( %$config );
@@ -176,7 +177,7 @@ Plack::Middleware::Greylist - throttle requests with different rates based on ne
 
 =head1 VERSION
 
-version v0.5.5
+version v0.5.6
 
 =head1 SYNOPSIS
 
@@ -281,7 +282,7 @@ The limit may be larger than L</default_rate>, to allow hosts to exceed the defa
 
 This is the path of the throttle count file used by the L</cache>.
 
-It is required unless you are defining your own L</cache>.
+It is required unless you are defining your own L</cache> or you have specified a C<share_file> in L</cache_config>.
 
 =head2 cache_config
 
@@ -302,7 +303,7 @@ application before forking, this should be false (default).
 
 C<unlink_on_exit>
 
-This defaults the negation of C<init_file>.
+When true, the cache file will be deleted on exit. This defaults the negation of C<init_file>.
 
 =item *
 
@@ -310,12 +311,14 @@ C<expire_time>
 
 This sets the expiration time, which defaults to 60 seconds.
 
-The L</retry_after> after attribute will default to 1 + C<expiry_time>.
+The L</retry_after> attribute will default to 1 + C<expiry_time>.
 
 =back
 
 Note that the L</file> attribute will be used to set the C<share_file>.
 
+See L<Cache::FastMmap/new> for more information.
+
 This option was added in v0.5.5.
 
 =head2 cache
